# -*- coding: utf-8 -*-
# Copyright 2021, CS GROUP - France, http://www.c-s.fr
#
# This file is part of EODAG project
#     https://www.github.com/CS-SI/EODAG
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""EODAG drivers package"""
from eodag.api.product.drivers.base import NoDriver  # noqa
from eodag_cube.api.product.drivers.sentinel2_l1c import Sentinel2L1C

DRIVERS = {"S2_MSI_L1C": Sentinel2L1C()}



# -*- coding: utf-8 -*-
# Copyright 2021, CS GROUP - France, http://www.c-s.fr
#
# This file is part of EODAG project
#     https://www.github.com/CS-SI/EODAG
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2

from eodag_cube.rpc.protocol import eodag_pb2 as eodag__pb2


class EOProductTypeStub(object):
    """EOProductTypeStub"""

    # missing associated documentation comment in .proto file
    pass

    def __init__(self, channel):
        """Constructor.

        Args:
          channel: A grpc.Channel.
        """
        self.ListProductTypes = channel.unary_stream(
            "/eodag.EOProductType/ListProductTypes",
            request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            response_deserializer=eodag__pb2.EOProductTypeSchema.FromString,
        )
        self.SearchProductType = channel.unary_stream(
            "/eodag.EOProductType/SearchProductType",
            request_serializer=eodag__pb2.EOProductTypeSearchRequest.SerializeToString,
            response_deserializer=eodag__pb2.EOProductTypeSchema.FromString,
        )


class EOProductTypeServicer(object):
    """EOProductTypeServicer"""

    # missing associated documentation comment in .proto file
    pass

    def ListProductTypes(self, request, context):
        """ListProductTypes"""
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def SearchProductType(self, request, context):
        """SearchProductType"""
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_EOProductTypeServicer_to_server(servicer, server):
    """add_EOProductTypeServicer_to_server"""
    rpc_method_handlers = {
        "ListProductTypes": grpc.unary_stream_rpc_method_handler(
            servicer.ListProductTypes,
            request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            response_serializer=eodag__pb2.EOProductTypeSchema.SerializeToString,
        ),
        "SearchProductType": grpc.unary_stream_rpc_method_handler(
            servicer.SearchProductType,
            request_deserializer=eodag__pb2.EOProductTypeSearchRequest.FromString,
            response_serializer=eodag__pb2.EOProductTypeSchema.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "eodag.EOProductType", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


class EOProductStub(object):
    """EOProductStub"""

    # missing associated documentation comment in .proto file
    pass

    def __init__(self, channel):
        """Constructor.

        Args:
          channel: A grpc.Channel.
        """
        self.SearchProduct = channel.unary_stream(
            "/eodag.EOProduct/SearchProduct",
            request_serializer=eodag__pb2.EOProductSearchRequest.SerializeToString,
            response_deserializer=eodag__pb2.EOProductInfo.FromString,
        )
        self.DownloadProduct = channel.unary_stream(
            "/eodag.EOProduct/DownloadProduct",
            request_serializer=eodag__pb2.EOProductDownloadRequest.SerializeToString,
            response_deserializer=eodag__pb2.NetCDFBuffer.FromString,
        )


class EOProductServicer(object):
    """EOProductServicer"""

    # missing associated documentation comment in .proto file
    pass

    def SearchProduct(self, request, context):
        """SearchProduct"""
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DownloadProduct(self, request, context):
        """DownloadProduct"""
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_EOProductServicer_to_server(servicer, server):
    """add_EOProductServicer_to_server"""
    rpc_method_handlers = {
        "SearchProduct": grpc.unary_stream_rpc_method_handler(
            servicer.SearchProduct,
            request_deserializer=eodag__pb2.EOProductSearchRequest.FromString,
            response_serializer=eodag__pb2.EOProductInfo.SerializeToString,
        ),
        "DownloadProduct": grpc.unary_stream_rpc_method_handler(
            servicer.DownloadProduct,
            request_deserializer=eodag__pb2.EOProductDownloadRequest.FromString,
            response_serializer=eodag__pb2.NetCDFBuffer.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "eodag.EOProduct", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))



# -*- coding: utf-8 -*-
# Copyright 2021, CS GROUP - France, http://www.c-s.fr
#
# This file is part of EODAG project
#     https://www.github.com/CS-SI/EODAG
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Miscellaneous utilities to be used throughout eodag.

Everything that does not fit into one of the specialised categories of utilities in
this package should go here
"""
from rasterio.crs import CRS

DEFAULT_PROJ = CRS.from_epsg(4326)



# -*- coding: utf-8 -*-
# Copyright 2021, CS GROUP - France, http://www.c-s.fr
#
# This file is part of EODAG project
#     https://www.github.com/CS-SI/EODAG
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
import logging

import numpy
import rasterio
import xarray as xr
from rasterio.enums import Resampling
from rasterio.vrt import WarpedVRT

from eodag.api.product._product import EOProduct as EOProduct_core
from eodag.utils.exceptions import DownloadError, UnsupportedDatasetAddressScheme

logger = logging.getLogger("eodag_cube.api.product")


class EOProduct(EOProduct_core):
    """A wrapper around an Earth Observation Product originating from a search.

    Every Search plugin instance must build an instance of this class for each of
    the result of its query method, and return a list of such instances. A EOProduct
    has a `location` attribute that initially points to its remote location, but is
    later changed to point to its path on the filesystem when the product has been
    downloaded. It also has a `remote_location` that always points to the remote
    location, so that the product can be downloaded at anytime if it is deleted from
    the filesystem. An EOProduct instance also has a reference to the search
    parameters that led to its creation.

    :param provider: The provider from which the product originates
    :type provider: str
    :param properties: The metadata of the product
    :type properties: dict

    .. note::
        The geojson spec `enforces <https://github.com/geojson/draft-geojson/pull/6>`_
        the expression of geometries as
        WGS84 CRS (EPSG:4326) coordinates and EOProduct is intended to be transmitted
        as geojson between applications. Therefore it stores geometries in the before
        mentioned CRS.
    """

    def __init__(self, *args, **kwargs):
        super(EOProduct, self).__init__(*args, **kwargs)

    def get_data(self, crs, resolution, band, extent):
        """Retrieves all or part of the raster data abstracted by the :class:`EOProduct`

        :param crs: The coordinate reference system in which the dataset should be
                    returned
        :type crs: str
        :param resolution: The resolution in which the dataset should be returned
                            (given in the unit of the crs)
        :type resolution: float
        :param band: The band of the dataset to retrieve (e.g.: 'B01')
        :type band: str
        :param extent: The coordinates on which to zoom as a tuple
                        (min_x, min_y, max_x, max_y) in the given `crs`
        :type extent: (float, float, float, float)
        :returns: The numeric matrix corresponding to the sub dataset or an empty
                    array if unable to get the data
        :rtype: xarray.DataArray
        """
        fail_value = xr.DataArray(numpy.empty(0))
        try:
            dataset_address = self.driver.get_data_address(self, band)
        except UnsupportedDatasetAddressScheme:
            logger.warning(
                "Eodag does not support getting data from distant sources by now. "
                "Falling back to first downloading the product and then getting the "
                "data..."
            )
            try:
                path_of_downloaded_file = self.download()
            except (RuntimeError, DownloadError):
                import traceback

                logger.warning(
                    "Error while trying to download the product:\n %s",
                    traceback.format_exc(),
                )
                logger.warning(
                    "There might be no download plugin registered for this EO product. "
                    "Try performing: product.register_downloader(download_plugin, "
                    "auth_plugin) before trying to call product.get_data(...)"
                )
                return fail_value
            if not path_of_downloaded_file:
                return fail_value
            dataset_address = self.driver.get_data_address(self, band)
        min_x, min_y, max_x, max_y = extent
        height = int((max_y - min_y) / resolution)
        width = int((max_x - min_x) / resolution)
        out_shape = (width, height)
        with rasterio.open(dataset_address) as src:
            with WarpedVRT(src, crs=crs, resampling=Resampling.bilinear) as vrt:
                array = vrt.read(
                    1,
                    window=vrt.window(*extent),
                    out_shape=out_shape,
                    resampling=Resampling.bilinear,
                )
                return xr.DataArray(array)

    def encode(self, raster, encoding="protobuf"):
        """Encode the subset to a network-compatible format.
        :param raster: The raster data to encode
        :type raster: xarray.DataArray
        :param encoding: The encoding of the export
        :type encoding: str
        :return: The data encoded in the specified encoding
        :rtype: bytes
        """
        # If no encoding return an empty byte
        if not encoding:
            logger.warning("Trying to encode a raster without specifying an encoding")
            return b""
        strategy = getattr(self, "_{encoding}".format(**locals()), None)
        if strategy:
            return strategy(raster)
        logger.error("Unknown encoding: %s", encoding)
        return b""

    def _protobuf(self, raster):
        """Google's Protocol buffers encoding strategy.
        :param raster: The raster to encode
        :type raster: xarray.DataArray
        :returns: The raster data represented by this subset in protocol buffers
                    encoding
        :rtype: bytes
        """
        from eodag_cube.api.product.protobuf import eo_product_pb2

        subdataset = eo_product_pb2.EOProductSubdataset()
        subdataset.id = self.properties["id"]
        subdataset.producer = self.provider
        subdataset.product_type = self.product_type
        subdataset.platform = self.properties["platformSerialIdentifier"]
        subdataset.sensor = self.properties["instrument"]
        data = subdataset.data
        data.array.extend(list(raster.values.flatten().astype(int)))
        data.shape.extend(list(raster.values.shape))
        data.dtype = raster.values.dtype.name
        return subdataset.SerializeToString()



# -*- coding: utf-8 -*-
# Copyright 2021, CS GROUP - France, http://www.c-s.fr
#
# This file is part of EODAG project
#     https://www.github.com/CS-SI/EODAG
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eo_product.proto

import sys

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pb2
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode("latin1"))

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor.FileDescriptor(
    name="eo_product.proto",
    package="eodag",
    syntax="proto3",
    serialized_pb=_b(
        '\n\x10\x65o_product.proto\x12\x05\x65odag">\n\x07NDArray\x12\x11\n\x05\x61rray\x18\x01 \x03(\x01\x42\x02\x10\x01\x12\x11\n\x05shape\x18\x02 \x03(\x07\x42\x02\x10\x01\x12\r\n\x05\x64type\x18\x03 \x01(\t"\x89\x01\n\x13\x45OProductSubdataset\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08producer\x18\x02 \x01(\t\x12\x14\n\x0cproduct_type\x18\x03 \x01(\t\x12\x10\n\x08platform\x18\x04 \x01(\t\x12\x0e\n\x06sensor\x18\x05 \x01(\t\x12\x1c\n\x04\x64\x61ta\x18\x06 \x01(\x0b\x32\x0e.eodag.NDArrayb\x06proto3'
    ),
)


_NDARRAY = _descriptor.Descriptor(
    name="NDArray",
    full_name="eodag.NDArray",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="array",
            full_name="eodag.NDArray.array",
            index=0,
            number=1,
            type=1,
            cpp_type=5,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            options=_descriptor._ParseOptions(
                descriptor_pb2.FieldOptions(), _b("\020\001")
            ),
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="shape",
            full_name="eodag.NDArray.shape",
            index=1,
            number=2,
            type=7,
            cpp_type=3,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            options=_descriptor._ParseOptions(
                descriptor_pb2.FieldOptions(), _b("\020\001")
            ),
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="dtype",
            full_name="eodag.NDArray.dtype",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=27,
    serialized_end=89,
)


_EOPRODUCTSUBDATASET = _descriptor.Descriptor(
    name="EOProductSubdataset",
    full_name="eodag.EOProductSubdataset",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="id",
            full_name="eodag.EOProductSubdataset.id",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="producer",
            full_name="eodag.EOProductSubdataset.producer",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="product_type",
            full_name="eodag.EOProductSubdataset.product_type",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="platform",
            full_name="eodag.EOProductSubdataset.platform",
            index=3,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="sensor",
            full_name="eodag.EOProductSubdataset.sensor",
            index=4,
            number=5,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="data",
            full_name="eodag.EOProductSubdataset.data",
            index=5,
            number=6,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=92,
    serialized_end=229,
)

_EOPRODUCTSUBDATASET.fields_by_name["data"].message_type = _NDARRAY
DESCRIPTOR.message_types_by_name["NDArray"] = _NDARRAY
DESCRIPTOR.message_types_by_name["EOProductSubdataset"] = _EOPRODUCTSUBDATASET
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

NDArray = _reflection.GeneratedProtocolMessageType(
    "NDArray",
    (_message.Message,),
    dict(
        DESCRIPTOR=_NDARRAY,
        __module__="eo_product_pb2"
        # @@protoc_insertion_point(class_scope:eodag.NDArray)
    ),
)
_sym_db.RegisterMessage(NDArray)

EOProductSubdataset = _reflection.GeneratedProtocolMessageType(
    "EOProductSubdataset",
    (_message.Message,),
    dict(
        DESCRIPTOR=_EOPRODUCTSUBDATASET,
        __module__="eo_product_pb2"
        # @@protoc_insertion_point(class_scope:eodag.EOProductSubdataset)
    ),
)
_sym_db.RegisterMessage(EOProductSubdataset)


_NDARRAY.fields_by_name["array"].has_options = True
_NDARRAY.fields_by_name["array"]._options = _descriptor._ParseOptions(
    descriptor_pb2.FieldOptions(), _b("\020\001")
)
_NDARRAY.fields_by_name["shape"].has_options = True
_NDARRAY.fields_by_name["shape"]._options = _descriptor._ParseOptions(
    descriptor_pb2.FieldOptions(), _b("\020\001")
)
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Copyright 2021, CS GROUP - France, http://www.c-s.fr
#
# This file is part of EODAG project
#     https://www.github.com/CS-SI/EODAG
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eodag.proto

import sys

from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode("latin1"))

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor.FileDescriptor(
    name="eodag.proto",
    package="eodag",
    syntax="proto3",
    serialized_pb=_b(
        '\n\x0b\x65odag.proto\x12\x05\x65odag\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x19google/protobuf/any.proto">\n\x1b\x45OProductTypeMetadataSchema\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x12\n\nvalue_type\x18\x02 \x01(\t"h\n\x13\x45OProductTypeSchema\x12\n\n\x02id\x18\x01 \x01(\t\x12\x30\n\x04meta\x18\x02 \x03(\x0b\x32".eodag.EOProductTypeMetadataSchema\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t"+\n\x1a\x45OProductTypeSearchRequest\x12\r\n\x05query\x18\x01 \x01(\t"\xae\x01\n\x16\x45OProductSearchRequest\x12\x14\n\x0cproduct_type\x18\x01 \x01(\t\x12\x11\n\tfootprint\x18\x02 \x01(\t\x12)\n\x05start\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\'\n\x03\x65nd\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x17\n\x0fmetadata_filter\x18\x05 \x01(\t"<\n\x08Metadata\x12\x0b\n\x03key\x18\x01 \x01(\t\x12#\n\x05value\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any">\n\rEOProductInfo\x12\n\n\x02id\x18\x01 \x01(\t\x12!\n\x08metadata\x18\x02 \x01(\x0b\x32\x0f.eodag.Metadata".\n\x18\x45OProductDownloadRequest\x12\x12\n\nproduct_id\x18\x02 \x01(\t"\x1f\n\x0cNetCDFBuffer\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\x0c\x32\xb3\x01\n\rEOProductType\x12J\n\x10ListProductTypes\x12\x16.google.protobuf.Empty\x1a\x1a.eodag.EOProductTypeSchema"\x00\x30\x01\x12V\n\x11SearchProductType\x12!.eodag.EOProductTypeSearchRequest\x1a\x1a.eodag.EOProductTypeSchema"\x00\x30\x01\x32\xa2\x01\n\tEOProduct\x12H\n\rSearchProduct\x12\x1d.eodag.EOProductSearchRequest\x1a\x14.eodag.EOProductInfo"\x00\x30\x01\x12K\n\x0f\x44ownloadProduct\x12\x1f.eodag.EOProductDownloadRequest\x1a\x13.eodag.NetCDFBuffer"\x00\x30\x01\x62\x06proto3'
    ),
    dependencies=[
        google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_any__pb2.DESCRIPTOR,
    ],
)


_EOPRODUCTTYPEMETADATASCHEMA = _descriptor.Descriptor(
    name="EOProductTypeMetadataSchema",
    full_name="eodag.EOProductTypeMetadataSchema",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="key",
            full_name="eodag.EOProductTypeMetadataSchema.key",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="value_type",
            full_name="eodag.EOProductTypeMetadataSchema.value_type",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=111,
    serialized_end=173,
)


_EOPRODUCTTYPESCHEMA = _descriptor.Descriptor(
    name="EOProductTypeSchema",
    full_name="eodag.EOProductTypeSchema",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="id",
            full_name="eodag.EOProductTypeSchema.id",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="meta",
            full_name="eodag.EOProductTypeSchema.meta",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="description",
            full_name="eodag.EOProductTypeSchema.description",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=175,
    serialized_end=279,
)


_EOPRODUCTTYPESEARCHREQUEST = _descriptor.Descriptor(
    name="EOProductTypeSearchRequest",
    full_name="eodag.EOProductTypeSearchRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="query",
            full_name="eodag.EOProductTypeSearchRequest.query",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=281,
    serialized_end=324,
)


_EOPRODUCTSEARCHREQUEST = _descriptor.Descriptor(
    name="EOProductSearchRequest",
    full_name="eodag.EOProductSearchRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="product_type",
            full_name="eodag.EOProductSearchRequest.product_type",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="footprint",
            full_name="eodag.EOProductSearchRequest.footprint",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="start",
            full_name="eodag.EOProductSearchRequest.start",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="end",
            full_name="eodag.EOProductSearchRequest.end",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="metadata_filter",
            full_name="eodag.EOProductSearchRequest.metadata_filter",
            index=4,
            number=5,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=327,
    serialized_end=501,
)


_METADATA = _descriptor.Descriptor(
    name="Metadata",
    full_name="eodag.Metadata",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="key",
            full_name="eodag.Metadata.key",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="value",
            full_name="eodag.Metadata.value",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=503,
    serialized_end=563,
)


_EOPRODUCTINFO = _descriptor.Descriptor(
    name="EOProductInfo",
    full_name="eodag.EOProductInfo",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="id",
            full_name="eodag.EOProductInfo.id",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="metadata",
            full_name="eodag.EOProductInfo.metadata",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=565,
    serialized_end=627,
)


_EOPRODUCTDOWNLOADREQUEST = _descriptor.Descriptor(
    name="EOProductDownloadRequest",
    full_name="eodag.EOProductDownloadRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="product_id",
            full_name="eodag.EOProductDownloadRequest.product_id",
            index=0,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=629,
    serialized_end=675,
)


_NETCDFBUFFER = _descriptor.Descriptor(
    name="NetCDFBuffer",
    full_name="eodag.NetCDFBuffer",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="content",
            full_name="eodag.NetCDFBuffer.content",
            index=0,
            number=1,
            type=12,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b(""),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=677,
    serialized_end=708,
)

_EOPRODUCTTYPESCHEMA.fields_by_name["meta"].message_type = _EOPRODUCTTYPEMETADATASCHEMA
_EOPRODUCTSEARCHREQUEST.fields_by_name[
    "start"
].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_EOPRODUCTSEARCHREQUEST.fields_by_name[
    "end"
].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_METADATA.fields_by_name["value"].message_type = google_dot_protobuf_dot_any__pb2._ANY
_EOPRODUCTINFO.fields_by_name["metadata"].message_type = _METADATA
DESCRIPTOR.message_types_by_name[
    "EOProductTypeMetadataSchema"
] = _EOPRODUCTTYPEMETADATASCHEMA
DESCRIPTOR.message_types_by_name["EOProductTypeSchema"] = _EOPRODUCTTYPESCHEMA
DESCRIPTOR.message_types_by_name[
    "EOProductTypeSearchRequest"
] = _EOPRODUCTTYPESEARCHREQUEST
DESCRIPTOR.message_types_by_name["EOProductSearchRequest"] = _EOPRODUCTSEARCHREQUEST
DESCRIPTOR.message_types_by_name["Metadata"] = _METADATA
DESCRIPTOR.message_types_by_name["EOProductInfo"] = _EOPRODUCTINFO
DESCRIPTOR.message_types_by_name["EOProductDownloadRequest"] = _EOPRODUCTDOWNLOADREQUEST
DESCRIPTOR.message_types_by_name["NetCDFBuffer"] = _NETCDFBUFFER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

EOProductTypeMetadataSchema = _reflection.GeneratedProtocolMessageType(
    "EOProductTypeMetadataSchema",
    (_message.Message,),
    dict(
        DESCRIPTOR=_EOPRODUCTTYPEMETADATASCHEMA,
        __module__="eodag_pb2"
        # @@protoc_insertion_point(class_scope:eodag.EOProductTypeMetadataSchema)
    ),
)
_sym_db.RegisterMessage(EOProductTypeMetadataSchema)

EOProductTypeSchema = _reflection.GeneratedProtocolMessageType(
    "EOProductTypeSchema",
    (_message.Message,),
    dict(
        DESCRIPTOR=_EOPRODUCTTYPESCHEMA,
        __module__="eodag_pb2"
        # @@protoc_insertion_point(class_scope:eodag.EOProductTypeSchema)
    ),
)
_sym_db.RegisterMessage(EOProductTypeSchema)

EOProductTypeSearchRequest = _reflection.GeneratedProtocolMessageType(
    "EOProductTypeSearchRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_EOPRODUCTTYPESEARCHREQUEST,
        __module__="eodag_pb2"
        # @@protoc_insertion_point(class_scope:eodag.EOProductTypeSearchRequest)
    ),
)
_sym_db.RegisterMessage(EOProductTypeSearchRequest)

EOProductSearchRequest = _reflection.GeneratedProtocolMessageType(
    "EOProductSearchRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_EOPRODUCTSEARCHREQUEST,
        __module__="eodag_pb2"
        # @@protoc_insertion_point(class_scope:eodag.EOProductSearchRequest)
    ),
)
_sym_db.RegisterMessage(EOProductSearchRequest)

Metadata = _reflection.GeneratedProtocolMessageType(
    "Metadata",
    (_message.Message,),
    dict(
        DESCRIPTOR=_METADATA,
        __module__="eodag_pb2"
        # @@protoc_insertion_point(class_scope:eodag.Metadata)
    ),
)
_sym_db.RegisterMessage(Metadata)

EOProductInfo = _reflection.GeneratedProtocolMessageType(
    "EOProductInfo",
    (_message.Message,),
    dict(
        DESCRIPTOR=_EOPRODUCTINFO,
        __module__="eodag_pb2"
        # @@protoc_insertion_point(class_scope:eodag.EOProductInfo)
    ),
)
_sym_db.RegisterMessage(EOProductInfo)

EOProductDownloadRequest = _reflection.GeneratedProtocolMessageType(
    "EOProductDownloadRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_EOPRODUCTDOWNLOADREQUEST,
        __module__="eodag_pb2"
        # @@protoc_insertion_point(class_scope:eodag.EOProductDownloadRequest)
    ),
)
_sym_db.RegisterMessage(EOProductDownloadRequest)

NetCDFBuffer = _reflection.GeneratedProtocolMessageType(
    "NetCDFBuffer",
    (_message.Message,),
    dict(
        DESCRIPTOR=_NETCDFBUFFER,
        __module__="eodag_pb2"
        # @@protoc_insertion_point(class_scope:eodag.NetCDFBuffer)
    ),
)
_sym_db.RegisterMessage(NetCDFBuffer)


_EOPRODUCTTYPE = _descriptor.ServiceDescriptor(
    name="EOProductType",
    full_name="eodag.EOProductType",
    file=DESCRIPTOR,
    index=0,
    options=None,
    serialized_start=711,
    serialized_end=890,
    methods=[
        _descriptor.MethodDescriptor(
            name="ListProductTypes",
            full_name="eodag.EOProductType.ListProductTypes",
            index=0,
            containing_service=None,
            input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
            output_type=_EOPRODUCTTYPESCHEMA,
            options=None,
        ),
        _descriptor.MethodDescriptor(
            name="SearchProductType",
            full_name="eodag.EOProductType.SearchProductType",
            index=1,
            containing_service=None,
            input_type=_EOPRODUCTTYPESEARCHREQUEST,
            output_type=_EOPRODUCTTYPESCHEMA,
            options=None,
        ),
    ],
)
_sym_db.RegisterServiceDescriptor(_EOPRODUCTTYPE)

DESCRIPTOR.services_by_name["EOProductType"] = _EOPRODUCTTYPE


_EOPRODUCT = _descriptor.ServiceDescriptor(
    name="EOProduct",
    full_name="eodag.EOProduct",
    file=DESCRIPTOR,
    index=1,
    options=None,
    serialized_start=893,
    serialized_end=1055,
    methods=[
        _descriptor.MethodDescriptor(
            name="SearchProduct",
            full_name="eodag.EOProduct.SearchProduct",
            index=0,
            containing_service=None,
            input_type=_EOPRODUCTSEARCHREQUEST,
            output_type=_EOPRODUCTINFO,
            options=None,
        ),
        _descriptor.MethodDescriptor(
            name="DownloadProduct",
            full_name="eodag.EOProduct.DownloadProduct",
            index=1,
            containing_service=None,
            input_type=_EOPRODUCTDOWNLOADREQUEST,
            output_type=_NETCDFBUFFER,
            options=None,
        ),
    ],
)
_sym_db.RegisterServiceDescriptor(_EOPRODUCT)

DESCRIPTOR.services_by_name["EOProduct"] = _EOPRODUCT

# @@protoc_insertion_point(module_scope)



import os

from setuptools import find_packages, setup

BASEDIR = os.path.dirname(os.path.abspath(os.path.realpath(__file__)))

metadata = {}
with open(os.path.join(BASEDIR, "eodag_cube", "__init__.py"), "r") as f:
    exec(f.read(), metadata)

with open(os.path.join(BASEDIR, "README.rst"), "r") as f:
    readme = f.read()

setup(
    name=metadata["__title__"],
    version=metadata["__version__"],
    description=metadata["__description__"],
    long_description=readme,
    author=metadata["__author__"],
    author_email=metadata["__author_email__"],
    url=metadata["__url__"],
    license=metadata["__license__"],
    packages=find_packages(exclude=("*.tests", "*.tests.*", "tests.*", "tests")),
    package_data={"": ["LICENSE"]},
    include_package_data=True,
    install_requires=[
        "eodag >= 2.0b2",
        "numpy",
        "rasterio",
        "protobuf",
        "grpcio",
        "xarray",
    ],
    extras_require={
        "dev": [
            "flake8",
            "isort",
            "pre-commit",
            "pytest==5.0.1",  # pytest pined to v5.0.1 to avoid issue when run from VSCode
            "pytest-cov",
            "tox",
            "nose",
            "faker",
            "coverage",
            "moto",
            "twine",
            "wheel",
        ]
    },
    zip_safe=False,
    entry_points={"console_scripts": ["eodag_cube=eodag_cube.eodag_cube:main"]},
    classifiers=[
        "Development Status :: 1 - Planning",
        "Intended Audience :: Developers",
        "Intended Audience :: Science/Research",
        "Natural Language :: English",
        "License :: OSI Approved :: Apache Software License",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: Implementation :: CPython",
        "Topic :: Scientific/Engineering :: GIS",
    ],
)
